@@ -7,6 +7,7 @@ from sahi.scripts.coco2yolov5 import main as coco2yolov5
 from sahi.scripts.coco_error_analysis import analyse
 from sahi.scripts.coco_evaluation import evaluate
 from sahi.scripts.slice_coco import slice
+from sahi.utils.import_utils import print_enviroment_info
 
 coco_app = {
     "evaluate": evaluate,
@@ -16,7 +17,13 @@ coco_app = {
     "yolov5": coco2yolov5,
 }
 
-sahi_app = {"predict": predict, "predict-fiftyone": predict_fiftyone, "coco": coco_app, "version": sahi_version}
+sahi_app = {
+    "predict": predict,
+    "predict-fiftyone": predict_fiftyone,
+    "coco": coco_app,
+    "version": sahi_version,
+    "env": print_enviroment_info,
+}
 
 
 def app() -> None:
